@@ -3,7 +3,7 @@ from selenium import webdriver
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
-from .objects import Experience, Education, Scraper, Interest, Accomplishment
+from .objects import Experience, Education, Scraper, Interest, Accomplishment, Contact
 import os
 
 
@@ -22,6 +22,7 @@ class Person(Scraper):
         accomplishments=[],
         company=None,
         job_title=None,
+        contacts=[],
         driver=None,
         get=True,
         scrape=True,
@@ -35,6 +36,7 @@ class Person(Scraper):
         self.interests = interests
         self.accomplishments = accomplishments
         self.also_viewed_urls = []
+        self.contacts = contacts
 
         if driver is None:
             try:
@@ -75,6 +77,9 @@ class Person(Scraper):
     def add_location(self, location):
         self.location = location
 
+    def add_contact(self, contact):
+        self.contacts.append(contact)
+
     def scrape(self, close_on_complete=True):
 
         if self.is_signed_in():
@@ -263,6 +268,25 @@ class Person(Scraper):
         except:
             pass
 
+        # get connections
+        try:
+            driver.get("https://www.linkedin.com/mynetwork/invite-connect/connections/")
+            _ = WebDriverWait(driver, 5).until(
+                EC.presence_of_element_located((By.CLASS_NAME, "mn-connections"))
+            )
+            connections = driver.find_element_by_class_name("mn-connections")
+            if connections is not None:
+                for conn in connections.find_elements_by_class_name("mn-connection-card"):
+                    anchor = conn.find_element_by_class_name("mn-connection-card__link")
+                    url = anchor.get_attribute("href")
+                    name = conn.find_element_by_class_name("mn-connection-card__details").find_element_by_class_name("mn-connection-card__name").text.strip()
+                    occupation = conn.find_element_by_class_name("mn-connection-card__details").find_element_by_class_name("mn-connection-card__occupation").text.strip()
+
+                    contact = Contact(name=name, occupation=occupation, url=url)
+                    self.add_contact(contact)
+        except:
+            connections = None
+
         if close_on_complete:
             driver.quit()
 
@@ -383,11 +407,12 @@ class Person(Scraper):
             return None
 
     def __repr__(self):
-        return "{name}\n\nAbout\n{about}\n\nExperience\n{exp}\n\nEducation\n{edu}\n\nInterest\n{int}\n\nAccomplishments\n{acc}".format(
+        return "{name}\n\nAbout\n{about}\n\nExperience\n{exp}\n\nEducation\n{edu}\n\nInterest\n{int}\n\nAccomplishments\n{acc}\n\nContacts\n{conn}".format(
             name=self.name,
             about=self.about,
             exp=self.experiences,
             edu=self.educations,
             int=self.interests,
             acc=self.accomplishments,
+            conn=self.contacts,
         )
